// $Id: businesscard.m,v 1.4.2.5 2014/10/16 17:22:31 rjs Exp $
//
// businesscard.m
//
// PDFlib client: businesscard example in Objective-C
//

#import "businesscard.h"

#if TARGET_OS_IPHONE
#import "PDFlib_ios/PDFlib_objc.h"
#else
#import "PDFlib/PDFlib_objc.h"
#endif

@implementation businesscard

+ (NSData *) run {
      
    NSData *pdfdata=nil;
    NSInteger         i, blockcontainer, page;
    NSString *infile = [[NSBundle mainBundle]
            pathForResource:@"boilerplate" ofType:@"pdf"];
    NSString *searchpath = [[NSBundle mainBundle] resourcePath];
    
    typedef struct { char *name; char *value; } blockdata;
    
    const blockdata data[] = {
        {"name",                     "Victor Kraxi"},
        {"business.title",           "Chief Paper Officer"},
        {"business.address.line1",   "17, Aviation Road"},
        {"business.address.city",    "Paperfield"},
        {"business.telephone.voice", "phone +1 234 567-89"},
        {"business.telephone.fax",   "fax +1 234 567-98"},
        {"business.email",           "victor@kraxi.com"},
        {"business.homepage",        "www.kraxi.com"},
    };

    const int BLOCKCOUNT = sizeof(data) / sizeof(blockdata);

    
    /* create a new PDFlib object */
    PDFlib *pdflib = [[PDFlib alloc] init];
    if (!pdflib) {
         return nil;
    }
    
    @try { 
        [pdflib set_option:@"errorpolicy=exception"];

        // Set the search path for fonts and PDF files
        [pdflib set_option:[NSString stringWithFormat:@"SearchPath={{%@}}", searchpath]];

        [pdflib begin_document:@"" optlist:@""];

        [pdflib set_info:@"Creator" value:@"businesscard.m"];
        [pdflib set_info:@"Author" value:@"Thomas Merz"];
        [pdflib set_info:@"Title" value:@"PDFlib block processing sample (Objective-C)"];
        
        blockcontainer = [pdflib open_pdi_document:infile optlist:@""];

        page = [pdflib open_pdi_page:blockcontainer pagenumber:1 optlist:@""];

        [pdflib begin_page_ext:20 height:20 optlist:@""]; // dummy page size

        // This will adjust the page size to the block container's size.
        [pdflib fit_pdi_page:page x:0 y:0 optlist:@"adjustpage"];

        // Fill all text blocks with dynamic data 
        for (i = 0; i < BLOCKCOUNT; i++) {
            [pdflib fill_textblock:page blockname:@(data[i].name)
                    text:@(data[i].value) optlist:@"embedding encoding=unicode"];
        }

        [pdflib end_page_ext:@""];
        [pdflib close_pdi_page:page];
        [pdflib end_document:@""];
        [pdflib close_pdi_document:blockcontainer];
        
        pdfdata = [pdflib get_buffer];
    } 
    @catch (PDFlibException *ex) { 
        NSString * errorMessage = 
	    [NSString stringWithFormat:@"PDFlib error %ld in '%@': %@",
            (long)[ex get_errnum], [ex get_apiname], [ex get_errmsg]];
#if TARGET_OS_IPHONE
        UIAlertView *alert = [[UIAlertView alloc] 
            initWithTitle:[ex name] message:errorMessage
            delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert show];
#else
        NSAlert *alert = [[NSAlert alloc] init];
        [alert setMessageText: errorMessage];
        [alert runModal];
#endif
    }
    @catch (NSException *ex) { 
#if TARGET_OS_IPHONE
        UIAlertView *alert = [[UIAlertView alloc] 
            initWithTitle:[ex name] message:[ex reason]
            delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert show];
#else
        NSAlert *alert = [[NSAlert alloc] init];
        [alert setMessageText: [ex reason]];
        [alert runModal];
#endif
    } 

    return pdfdata;
}

@end
